@@ -4,5 +4,6 @@ vffgm <- function(C, u, tht){
 	a = -(1 - u)*tht
 	b = 1 + (1 - u)*tht
 	c = -C/u
-	return((-b + sqrt(b*b - 4*a*c))/(2*a))
+	r = ((-b + sqrt(b*b - 4*a*c))/(2*a))
+	return(ifelse(r > 1, NaN, ifelse(r < 0, NaN, r)))
 }
